@@ -49,5 +49,5 @@ def get_input(question_number):
     })
     response = requests.get('https://teach-anya.herokuapp.com/get-big-input', data=str.encode(j))
     r = response.text
-    print(f"Got json input (length={len(response.text)}) Don't forget to decode it!")
+    print(f"Got json input (number of characters={len(response.text)}) Don't forget to decode it!")
     return r
\ No newline at end of file
